/*
 * Copyright (c) 2008 appspy.org, Contributors.
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License.
 *  
 * You may obtain a copy of the License at 
 * 	http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the 
 * License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, 
 * either express or implied. See the License for the specific language governing permissions 
 * and limitations under the License. */

package org.appspy.server.dao.xml;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.appspy.server.bo.Dashboard;
import org.appspy.server.bo.DashboardColumn;
import org.appspy.server.bo.DashboardParamBinding;
import org.appspy.server.bo.DashboardReport;
import org.appspy.server.bo.Report;
import org.appspy.server.bo.ReportParam;
import org.appspy.server.dao.ReportDao;
import org.appspy.server.xml.XmlDashboard;
import org.appspy.server.xml.XmlDashboardColumn;
import org.appspy.server.xml.XmlDashboardParamBinding;
import org.appspy.server.xml.XmlDashboardReport;
import org.appspy.server.xml.XmlReportParam;

/**
 * @author Olivier HEDIN / olivier@appspy.org
 */
public class XmlDashboardDataLoader implements XmlDataLoader {
	
	protected static Log sLog = LogFactory.getLog(XmlDashboardDataLoader.class);
	
	protected ReportDao mReportDao = null;

	/* (non-Javadoc)
	 * @see org.appspy.server.dao.xml.XmlDataLoader#loadData(java.util.Collection)
	 */
	public void loadData(Object data) {
		XmlDashboard xd = (XmlDashboard) data;
		
		Dashboard d = mReportDao.findDashboardByName(xd.getName());
		if (d == null)
		{
			d = new Dashboard();
			d.setName(xd.getName());
			d.setCategory(mReportDao.findReportCategoryByName(xd.getReportCategoryName()));
			for (XmlReportParam xrp : xd.getReportParams()) {
				ReportParam rp = new ReportParam();
				rp.setName(xrp.getName());
				rp.setAsk(xrp.isAsk());
				rp.setPrompt(xrp.getPrompt());
				rp.setDefault(xrp.getDefault());
				rp.setChooser(mReportDao.findReportParamChooserByName(xrp.getChooser()));
				rp.setDashboard(d);
				d.getParams().add(rp);
			}
			for (XmlDashboardColumn xdc : xd.getDashboardColumns())
            {
	            DashboardColumn dc = new DashboardColumn();
	            dc.setDashboard(d);
	            dc.setIndex(xdc.getIndex());
	            dc.setWidth(xdc.getWidth());
	            d.getColumns().add(dc);
	            for (XmlDashboardReport xdr : xdc.getDashboardReports())
                {
	                DashboardReport dr = new DashboardReport();
	                dr.setDashboardColumn(dc);
	                dr.setHeight(xdr.getHeight());
	                Report report = mReportDao.findReportByName(xdr.getReportName());
	                dr.setReport(report);
	                dr.setRowIndex(xdr.getRowIndex());
	                dr.setTitle(xdr.getTitle());
	                dc.getDashboardReports().add(dr);
	                for (XmlDashboardParamBinding xdpb : xdr.getDashboardParamBindings())
                    {
	                    DashboardParamBinding dpb = new DashboardParamBinding();
	                    dr.getDashboardParamBindings().add(dpb);
	                    dpb.setDashboardReport(dr);
	                    ReportParam dashboardParam = null;
	                    ReportParam reportParam = null;
	                    for (ReportParam p : d.getParams())
                        {
	                        if (p.getName().equals(xdpb.getDashboardParamName()))
	                        {
	                        	dashboardParam = p;
	                        }
                        }
	                    for (ReportParam p : report.getParams())
                        {
	                        if (p.getName().equals(xdpb.getReportParamName()))
	                        {
	                        	reportParam = p;
	                        }
                        }
	                    dpb.setDashboardParam(dashboardParam);
	                    dpb.setReportParam(reportParam);
                    }
                }
            }
			mReportDao.saveDashboard(d);
		}
	}

	/**
	 * @return the reportDao
	 */
	public ReportDao getReportDao() {
		return mReportDao;
	}

	/**
	 * @param reportDao the reportDao to set
	 */
	public void setReportDao(ReportDao reportDao) {
		mReportDao = reportDao;
	}

	
}
