/*
 * Copyright (c) 2008 appspy.org, Contributors.
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License.
 *  
 * You may obtain a copy of the License at 
 * 	http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the 
 * License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, 
 * either express or implied. See the License for the specific language governing permissions 
 * and limitations under the License. */

package org.appspy.server.dao.xml;

import java.io.ByteArrayOutputStream;
import java.io.IOException;

import org.apache.commons.io.IOUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.appspy.server.bo.Report;
import org.appspy.server.bo.ReportParam;
import org.appspy.server.dao.ReportDao;
import org.appspy.server.xml.XmlReport;
import org.appspy.server.xml.XmlReportParam;
import org.springframework.core.io.ClassPathResource;

/**
 * @author Olivier HEDIN / olivier@appspy.org
 */
public class XmlReportDataLoader implements XmlDataLoader {
	
	protected static Log sLog = LogFactory.getLog(XmlReportDataLoader.class);
	
	protected ReportDao mReportDao = null;

	/* (non-Javadoc)
	 * @see org.appspy.server.dao.xml.XmlDataLoader#loadData(java.util.Collection)
	 */
	public void loadData(Object data) {
		XmlReport xr = (XmlReport) data;
		
		Report r = mReportDao.findReportByName(xr.getName());
		if (r == null)
		{
			r = new Report();
			r.setName(xr.getName());
			r.setCategory(mReportDao.findReportCategoryByName(xr.getReportCategoryName()));
			r.setReportingSystem(mReportDao.findReportingSystemByName(xr.getReportingSystem()));
			// TODO: setReportContent
			if (xr.getReportContentPath() != null)
			{
				try {
					ClassPathResource cpr = new ClassPathResource(xr.getReportContentPath());
					ByteArrayOutputStream baos = new ByteArrayOutputStream();
					IOUtils.copy(cpr.getInputStream(), baos);
					r.setReportContent(baos.toByteArray());
				} catch (IOException e) {
					sLog.error("Error when importing report content for report : " + xr.getName(), e);
				}
			}
			for (XmlReportParam xrp : xr.getReportParams()) {
				ReportParam rp = new ReportParam();
				rp.setName(xrp.getName());
				rp.setAsk(xrp.isAsk());
				rp.setPrompt(xrp.getPrompt());
				rp.setDefault(xrp.getDefault());
				rp.setChooser(mReportDao.findReportParamChooserByName(xrp.getChooser()));
				rp.setReport(r);
				r.getParams().add(rp);
			}
			mReportDao.saveReport(r);
		}
	}

	/**
	 * @return the reportDao
	 */
	public ReportDao getReportDao() {
		return mReportDao;
	}

	/**
	 * @param reportDao the reportDao to set
	 */
	public void setReportDao(ReportDao reportDao) {
		mReportDao = reportDao;
	}

	
}
